<?php
// Exit if accessed directly
if (!defined('ABSPATH')) exit;
require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
add_filter('plugin_row_meta','dpd_plugin_meta', 10, 2);
function dpd_plugin_meta($meta,$file){
    if (plugin_basename(DBX_DPD_PLUGIN_FILE) === $file){
        foreach ($meta as $link) {
            if (strpos($link, 'tab=plugin-information') !== false) {
                return $meta;
            }
        } 
        $our_plugin = get_plugin_data(DBX_DPD_PLUGIN_FILE);
        $meta[] = sprintf(
            '<a href="%s" class="plugin-settings" aria-label="%s" data-title="%s">%s</a>',
            esc_url(admin_url('options-general.php?page=dbx-dpd-settings-page')),
            esc_attr(sprintf(esc_html__('Setari plugin %s','woo-dbx-dpd'), $our_plugin['Name'])),
            esc_attr($our_plugin['Name']),
            esc_html__('Setari DPD','woo-dbx-dpd')
            );
        $meta[] = sprintf(
            '<a href="%s" class="thickbox open-plugin-details-modal" aria-label="%s" data-title="%s">%s</a>',
            esc_url(admin_url('plugin-install.php?tab=plugin-information&plugin=woocommerce-dbx-dpd&TB_iframe=true&width=600&height=550')),
            esc_attr(sprintf(esc_html__('Mai multe informații despre %s','woo-dbx-dpd'), $our_plugin['Name'])),
            esc_attr($our_plugin['Name']),
            esc_html__('Vezi Detalii','woo-dbx-dpd')
        );    
        $meta[] = sprintf(
            '<a href="%s" target="_blank">%s</a>',
            esc_url('https://dabex.eu/?utm_source=woocommerce&utm_medium='.$our_plugin['TextDomain'].'&utm_campaign="'.get_site_url().'"'),
            esc_html__('Cere Ajutor','woo-dbx-dpd')
            );    
    }
    return $meta;
}
add_filter ('plugins_api', 'dpd_plugin_info', 20, 3);
function dpd_plugin_info( $res, $action, $args ){
	if( 'plugin_information' !== $action ) {
		return false;
	}
	$plugin_slug = 'woocommerce-dbx-dpd'; 
	if( $plugin_slug !== $args->slug ) {
		return false;
	}
	if( false == $remote = get_transient( 'dbx_dpd_update' . $plugin_slug ) ) {
		$remote = wp_remote_get( DBX_DPD_JSON, array(
			'timeout' => 10,
			'headers' => array(
				'Accept' => 'application/json'
			) )
		);
		if ( ! is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && ! empty( $remote['body'] ) ) {
			set_transient( 'dbx_dpd_update' . $plugin_slug, $remote, 43200 ); // 12 hours cache
		}
	}
	if( ! is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && ! empty( $remote['body'] ) ) {
		$remote = json_decode( $remote['body'] );
		$res                    = new stdClass();
		$res->name              = $remote->name;
		$res->slug              = $plugin_slug;
		$res->version           = $remote->version;
		$res->tested            = $remote->tested;
		$res->requires          = $remote->requires;
		$res->author            = '<a href="https://dabex.eu">Dabex Agency</a>';
		$res->author_profile    = 'https://dabex.eu';
		$res->download_link     = $remote->download_url;
		$res->trunk             = $remote->download_url;
		$res->requires_php      = $remote->requires_php;
		$res->last_updated      = $remote->last_updated;
		$res->sections          = array(
			'description'               => $remote->sections->description,
			'changelog'                 => $remote->sections->changelog,
			'asistenta_woocommerce'     => $remote->sections->help,
			'screenshots'               => $remote->screenshots
		);
		$res->banners = array(
		    'low'  => $remote->banners->low,
			'high' => $remote->banners->high
		);
		return $res;
	}
	return false;
}
add_filter('site_transient_update_plugins', 'dpd_plugin_update' );
function dpd_plugin_update( $transient ){
    $current_version = get_plugin_data(DBX_DPD_PLUGIN_FILE)['Version'];
	if ( empty($transient->checked ) ) {
            return $transient;
        }
	if( false == $remote = get_transient( 'dbx_dpd_update' ) ) {
		$remote = wp_remote_get( DBX_DPD_JSON, array(
			'timeout' => 10,
			'headers' => array(
				'Accept' => 'application/json'
			) )
		);
		if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && !empty( $remote['body'] ) ) {
			set_transient( 'dbx_dpd_update', $remote, 43200 );
		}
	}
	if( $remote ) {
		$remote = json_decode( $remote['body'] );
		if( $remote && version_compare( $current_version, $remote->version, '<' ) && version_compare($remote->requires, get_bloginfo('version'), '<' ) ) {
			$res                = new stdClass();
			$res->slug          = 'woocommerce-dbx-dpd';
			$res->plugin        = 'woocommerce-dbx-dpd/woocommerce-dbx-dpd.php'; 
			$res->new_version   = $remote->version;
			$res->tested        = $remote->tested;
			$res->package       = $remote->download_url;
			$res->requires_php  = $remote->requires_php;
           	$transient->response[$res->plugin] = $res;
           	$transient->checked[$res->plugin] = $remote->version;
           	}
	}
        return $transient;
}
add_action( 'upgrader_process_complete', 'dpd_after_update', 10, 2 );
function dpd_after_update( $upgrader_object, $options ) {
	if ( $options['action'] == 'update' && $options['type'] === 'plugin' )  {
		delete_transient( 'dbx_dpd_update' );
	}
}
register_activation_hook(DBX_DPD_PLUGIN_FILE, 'create_dpd_table_localities');
function create_dpd_table_localities(){
	global $wpdb;
	$db_table_name = 'dpd_localities';
    $charset_collate = $wpdb->get_charset_collate();
	if($wpdb->get_var( "show tables like '$db_table_name'" ) != $db_table_name ) {
    $sql = "CREATE TABLE $db_table_name (
            id int(20) DEFAULT NULL,
            countryId int(20) NOT NULL,
            name varchar(255) NOT NULL,
            region varchar(255) NOT NULL,
            region_code varchar(255) NOT NULL,
            postCode int(20) NOT NULL,
            servingOfficeId int(20) NOT NULL,
            servingHubOfficeId int(20) NOT NULL,
            UNIQUE KEY id (id)
        ) $charset_collate;";
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql );
    }
}
register_activation_hook(DBX_DPD_PLUGIN_FILE, 'dbx_dpd_insert_localities');
function dbx_dpd_insert_localities(){
    global $wpdb;
    $db_table_name = 'dpd_localities';
    $remote = wp_remote_get( DBX_DPD_API.'/localitati_dpd.json', array(
			'timeout' => 10,
			'headers' => array(
				'Accept' => 'application/json'
			) )
		);
	if( ! is_wp_error( $remote ) && isset( $remote['response']['code'] ) && $remote['response']['code'] == 200 && ! empty( $remote['body'] ) ) {
		$remote = json_decode( $remote['body'] );
		foreach ($remote as $loc){
		    $db_data = [
		        'id'                    => $loc->id,
		        'countryId'             => $loc->countryId,
		        'name'                  => ucwords(strtolower($loc->name)),
		        'region'                => ucwords(strtolower($loc->region)),
		        'region_code'           => dbx_get_county_code(ucwords(strtolower($loc->region))),
		        'postCode'              => $loc->postCode,
		        'servingOfficeId'       => $loc->servingOfficeId,
		        'servingHubOfficeId'    => $loc->servingHubOfficeId
		        ];
		    $wpdb->insert($db_table_name, $db_data);
		}
	}
}
register_deactivation_hook(DBX_DPD_PLUGIN_FILE, 'dbx_dpd_deactivate');
function dbx_dpd_deactivate(){
	global $wpdb;
	$db_table_name = 'dpd_localities';
	$wpdb->query("DROP TABLE IF EXISTS $db_table_name;");
}