<?php

if (!defined('ABSPATH')) {
    exit;
}
// Exit if accessed directly
// Check if WooCommerce is active
if (is_woocommerce_active()) {
    class DPD_city_select{
        const VERSION = '1.0.0';
        private $plugin_path;
        private $plugin_url;
        private $cities;
        public function __construct(){
            add_filter('woocommerce_billing_fields', array($this, 'billing_fields'), 10, 2);
            add_filter('woocommerce_shipping_fields', array($this, 'shipping_fields'), 10, 2);
            add_filter('woocommerce_form_field_city', array($this, 'form_field_city'), 10, 4);
            add_action('wp_enqueue_scripts', array($this, 'load_scripts'));
        }
        public function billing_fields($fields, $country){
            $fields['billing_city']['type'] = 'city';
            return $fields;
        }
        public function shipping_fields($fields, $country){
            $fields['shipping_city']['type'] = 'city';
            return $fields;
        }
        public function get_cities($cc = null){
            if (empty($this->cities)) {
                $this->load_country_cities();
            }
            if (!is_null($cc)) {
                return isset($this->cities[$cc]) ? $this->cities[$cc] : false;
            } else {
                return $this->cities;
            }
        }
        public function load_country_cities(){
            global $cities;
            $this->cities = apply_filters('dpd_city_select_cities', $cities);
        }
        public function form_field_city($field, $key, $args, $value){
            if ((!empty($args['clear']))) {
                $after = '<div class="clear"></div>';
            } else {
                $after = '';
            }
            if ($args['required']) {
                $args['class'][] = 'validate-required';
                $required = ' <abbr class="required" title="' . esc_attr__('required', 'woocommerce') . '">*</abbr>';
            } else {
                $required = '';
            }
            $custom_attributes = array();
            if (!empty($args['custom_attributes']) && is_array($args['custom_attributes'])) {
                foreach ($args['custom_attributes'] as $attribute => $attribute_value) {
                    $custom_attributes[] = esc_attr($attribute) . '="' . esc_attr($attribute_value) . '"';
                }
            }
            if (!empty($args['validate'])) {
                foreach ($args['validate'] as $validate) {
                    $args['class'][] = 'validate-' . $validate;
                }
            }
            $field = '<p class="form-row ' . esc_attr(implode(' ', $args['class'])) . '" id="' . esc_attr($args['id']) . '_field">';
            if ($args['label']) {
                $field .= '<label for="' . esc_attr($args['id']) . '" class="' . esc_attr(implode(' ', $args['label_class'])) . '">' . $args['label'] . $required . '</label>';
            }
            $country_key = $key == 'billing_city' ? 'billing_country' : 'shipping_country';
            $current_country = WC()->checkout->get_value($country_key);
            $cart_selected_city = WC()->session->get('customer')['shipping_city'] ?: null;
            $cart_selected_county = WC()->session->get('customer')['shipping_state'] ?: null;
            $cities = $this->get_cities($current_country);
            if (is_array($cities)) {
                $field .= '<select name="' . esc_attr($key) . '" id="' . esc_attr($args['id']) . '" class="city_select ' . esc_attr(implode(' ', $args['input_class'])) . '" ' . implode(' ', $custom_attributes) . ' placeholder="' . esc_attr($args['placeholder']) . '"><option value="">' . __('Selectati localitatea&hellip;', 'woocommerce') . '</option>';
            if ($cart_selected_county && $cities[$cart_selected_county]) {
                $dropdown_cities = $cities[$cart_selected_county];
                foreach ($dropdown_cities as $city_name) {
                    $field .= '<option value="' . esc_attr($city_name) . '" ' . selected($value, $city_name, false) . '>' . $city_name . '</option>';
                }
            }
            $field .= '</select>';
                if ($cart_selected_county) {
                $field .= '
                    <script>
                        jQuery("#billing_state").val("' . $cart_selected_county . '").trigger("change");
                    </script>
                    ';
                }
                if ($cart_selected_city) {
                $field .= '
                    <script>
                        jQuery("#billing_city").val("' . $cart_selected_city . '").trigger("change");
                    </script>
                    ';
                }
            } else {
                $field .= '<input type="text" class="input-text ' . esc_attr(implode(' ', $args['input_class'])) . '" value="' . esc_attr($value) . '"  placeholder="' . esc_attr($args['placeholder']) . '" name="' . esc_attr($key) . '" id="' . esc_attr($args['id']) . '" ' . implode(' ', $custom_attributes) . ' />';
            }
            if ($args['description']) {
                $field .= '<span class="description">' . esc_attr($args['description']) . '</span>';
            }
            $field .= '</p>' . $after;
            return $field;
        }
        public function load_scripts()
        {
            if (is_cart() || is_checkout() || is_wc_endpoint_url('edit-address')) {
                $city_select_path = plugin_dir_url( __FILE__ ) . '/js/city-select.js';
                wp_enqueue_script('dpd-city-select', $city_select_path, array('jquery', 'woocommerce'), self::VERSION, true);
                $cities = json_encode($this->get_cities());
                wp_localize_script('dpd-city-select', 'wc_city_select_params', array(
                    'cities' => $cities,
                    'i18n_select_city_text' => esc_attr__('Select an option&hellip;', 'woocommerce'),
                ));
            }
        }
    }
    $GLOBALS['dpd_city_select'] = new DPD_city_select();
}

add_filter('dpd_city_select_cities', 'dpd_cities');
if (!function_exists('dpd_cities')) {
    function dpd_cities($cities){
        global $wpdb;
        $query = 'SELECT * FROM dpd_localities WHERE 1=1 ';
        $cityList = $wpdb->get_results($query);
        $cities['RO'] = array();
        foreach ($cityList as $city) {
            $cities['RO'][$city->region_code][] = $city->name;
        }
        return $cities;
    }
}
add_filter('woocommerce_states', 'custom_woocommerce_states');
if (!function_exists('custom_woocommerce_states')) {
    function custom_woocommerce_states($states)
    {
        $states['RO'] = dbx_get_counties();
        return $states;
    }
}

add_filter('woocommerce_default_address_fields', 'dbx_dpd_woocommerce_field_order');
if (!function_exists('dbx_dpd_woocommerce_field_order')) {
    function dbx_dpd_woocommerce_field_order($fields)
    {
        $fields['state']['priority'] = 80;
        $fields['city']['priority'] = 85;
        return $fields;
    }
}
add_filter('default_checkout_billing_country', 'change_default_checkout_country_billing');
add_filter('default_checkout_shipping_country', 'change_default_checkout_country_shipping');
add_filter('default_checkout_billing_state', 'change_default_checkout_state_billing');
add_filter('default_checkout_shipping_state', 'change_default_checkout_state_shipping');
if (!function_exists('change_default_checkout_country_billing')) {
    function change_default_checkout_country_billing()
    {
        if (!in_array(get_option('woocommerce_default_customer_address'), ['geolocation_ajax', 'geolocation']))
            return 'RO'; // country code
    }
}
if (!function_exists('change_default_checkout_state_billing')) {
    function change_default_checkout_state_billing()
    {
        if (!in_array(get_option('woocommerce_default_customer_address'), ['geolocation_ajax', 'geolocation']))
            return 'B'; // state code
    }
}
if (!function_exists('change_default_checkout_country_shipping')) {
    function change_default_checkout_country_shipping()
    {
        if (!in_array(get_option('woocommerce_default_customer_address'), ['geolocation_ajax', 'geolocation']))
            return 'RO'; // country code
    }
}
if (!function_exists('change_default_checkout_state_shipping')) {
    function change_default_checkout_state_shipping()
    {
        if (!in_array(get_option('woocommerce_default_customer_address'), ['geolocation_ajax', 'geolocation']))
            return 'B'; // state code
    }
}
