<?php
// Check if WooCommerce is active
if (is_woocommerce_active()) {
    function DPD_Shipping_Method(){
        if (!class_exists('DPD_Shipping_Method')) {
            class DPD_Shipping_Method extends WC_Shipping_Method{
                public function __construct(){
                    $this->id                 = 'dbx-dpd';
                    $this->method_title       = esc_html__('Livrare DPD Curier', 'woo-dbx-dpd');
                    $this->method_description = esc_html__('Livrare DPD Curier', 'woo-dbx-dpd');

                    // Availability & Countries
                    $this->availability = 'including';
                    $this->countries = array('RO');

                    $this->init();

                    $this->title = isset($this->settings['title']) ? $this->settings['title'] : esc_html__('Livrare DPD Curier', 'woo-dbx-dpd');
                }
                function init(){
                    $this->init_form_fields();
                    $this->init_settings();
                    add_action('woocommerce_update_options_shipping_' . $this->id, array($this, 'process_admin_options'));
                }
                function init_form_fields(){
                    $this->form_fields = array(
                        'title' => array(
                            'title' => esc_html__('Denumire metoda livrare *', 'woo-dbx-dpd'),
                            'type' => 'text',
                            'description' => esc_html__('Denumirea metodei de livrare in Cart si Checkout.', 'woo-dbx-dpd'),
                            'default' => esc_html__('DPD Curier', 'woo-dbx-dpd'),
                            'desc_tip'      => true,
                            'custom_attributes' => array('required' => 'required')
                        ),
                        'tarif_contract_dbx_dpd' => array(
                            'title'         => esc_html__('Afisare tarif contract', 'woo-dbx-dpd'),
                            'type'          => 'select',
                            'default'       => 'yes',
                            'css'           => 'width:400px;',
                            'description' => esc_html__('Activați această opțiune pentru a calcula costul transportului în funcție de contractul dvs. DPD.', 'woo-dbx-dpd'),
                            'desc_tip'      => true,
                            'options'       => array(
                                'yes'       => esc_html__('Da', 'woo-dbx-dpd'),
                                'no'        => esc_html__('Nu', 'woo-dbx-dpd')
                            ),
                        ),
                        'prag_gratis' => array(
                            'title'     => esc_html__('Prag Transport Gratuit', 'woo-dbx-dpd'),
                            'type'      => 'text',
                            'default'   => esc_html__('200', 'woo-dbx-dpd')
                        ),
                        'tarif_implicit' => array(
                            'title'         => esc_html__('Tarif implicit', 'woo-dbx-dpd'),
                            'type'          => 'number',
                            'default'       => esc_html__('17', 'woo-dbx-dpd'),
                            'desc_tip'      => true,
                            'custom_attributes' => array('step' => '0.01', 'min' => '0'),
                            'description'   => esc_html__('Costul implicit de livrare, pentru comenzile care au o valoare mai mică decât pragul setat mai sus, pentru transport gratuit.', 'woo-dbx-dpd')
                        ),
                        'cost_transport_maxim' => array(
                            'title'         => esc_html__('Tarif Transport Maxim', 'woo-dbx-dpd'),
                            'type'          => 'text',
                            'default'       => esc_html__('40', 'woo-dbx-dpd'),
                            'desc_tip'      => true,
                            'description'   => esc_html__('Tariful final nu poate depasi aceasta valoare.', 'woo-dbx-dpd')
                        ),
                    );
                }
                public function admin_options(){
                    echo '<h1>DPD Curier - Setări Livrare</h1><br/><table class="form-table">';
                    echo '<span>Modalitatea de livrare DPD Curier este valabilă doar pentru livrarea în România.</span>';
                    $this->generate_settings_html();
                    echo '</table>';
                }
                private function fix_format($value){
                    $value = str_replace(',', '.', $value);
                    return $value;
                }
                public function calculate_shipping($package = array()){
                    $prag_gratis        = $this->get_option('prag_gratis');
                    $tarif_implicit = $this->get_option('tarif_implicit');
                    $tarif_contract = $this->get_option('tarif_contract_dbx_dpd');
                    $tarif_maxim = $this->get_option('cost_transport_maxim');
                    if (empty($tarif_maxim)) $tarif_maxim = 99999;
                    $settings = (array) get_option( 'dbx-dpd-plugin-settings' );
                    $oras = $package['destination']['city'] ?? '';
                    $postcode = $package['destination']['postcode'] ?? '';
                    $judet = $package['destination']['state'] ?? '';
                    $ramburs = 0;
                    $greutate = 0;
                    foreach ($package['contents'] as $product) {
                        $ramburs += ($product['line_total'] + $product['line_tax']);
                        // WooCommerce 3.0 or later.
                        if (method_exists($product['data'], 'get_height')) {
                            $greutate += $this->fix_format($product['data']->get_weight() ?: 1) * $product['quantity'];
                        } 
                    }
                    $weight_type = get_option('woocommerce_weight_unit');
                    if ($weight_type == 'g') {
                        $greutate = $greutate / 1000;
                    }
                    if ($greutate < 1) {
                        $greutate = 1;
                    } else {
                        $greutate = round($greutate);
                    }
                    $label = $this->title;
                    if ($prag_gratis && ($ramburs >= $prag_gratis)) {
                        $transport = 0;
                        $label .= ': '.esc_html__('Gratuit','woo-dbx-dpd');
                    } 
                    else {
                        if ($tarif_contract == 'yes') {
                        $vars = array(
                            'username_dpd'  => $settings['dbx_dpd_username'],
                            'password_dpd'  => $settings['dbx_dpd_pass'], 
                            'service_id'    => $settings['dbx_dpd_service_id'],
                            'nr_colete'     => $settings['dbx_dpd_nr_colete'],
                            'countryId'     => '642',
                            'recipient_name' => 'Calcul Livrare',
                            'private' => 'false',
                            'payer' => 'SENDER',
                            'greutate' => $greutate,
                            'site_id'       => get_site_id($oras, $judet),
                            //'site_name' => $oras,
                            'state_id' => $judet,
                            'val_ramburs'   =>$ramburs,
                            'postcode' => $postcode,
                            'currency'  => 'RON',
                            'val_decl'  => '0',
                            'fragile'   => 'false'
                            );
                        $data = json_encode($vars);
                        $transport = (float) $this->get_option('tarif_implicit') ?: 0;
                        if ($judet && $oras) {
                            $raspuns= (new WOO_DPD_API)->calc_shipping_cost($data);
                            $transport = $raspuns;
                        if ($ramburs > $prag_gratis) {
                            $transport = 0;
                        }
                        if ($transport == 0) $label = $this->title . ': Gratuit';
                        }
                        } 
                        else{
                        if ($judet && $oras) {
                            if ($ramburs < $prag_gratis) $transport = $tarif_implicit;
                            if ($ramburs >= $prag_gratis) $transport = 0;
                            if ($transport == 0) $label = $this->title . ': Gratuit';
                            }
                            else {
                                $transport = (float) $tarif_implicit ?: 0;
                            }    
                        }
                    }
                    $transport = min($transport, $tarif_maxim);
                    $args = array(
                        'id'    => $this->id,
                        'label' => $label,
                        'cost'  => $transport,
                        'taxes' => true
                    );
                        $this->add_rate($args);
                    
                } // end method
            } // end class
        } // end ifclass exist
    } // end function
add_action('woocommerce_shipping_init', 'DPD_Shipping_Method');
} // end if